@@ -4,7 +4,7 @@ from typing import Dict
 from httpx import AsyncClient, Response
 from typing import Optional, List, Dict, Type
 from httpx import Response
-from .exceptions import get_exception_from_status_code
+from exceptions import get_exception_from_status_code
 
 
 _xcsrf_allowed_methods: Dict[str, bool] = {
@@ -72,7 +72,6 @@ class Requests:
         response = await self.session.request(method, *args, **kwargs)
         if skip_roblox:
             return response
-
         method = method.lower()
         if handle_xcsrf_token and self.xcsrf_token_name in response.headers and _xcsrf_allowed_methods.get(method):
             self.session.headers[self.xcsrf_token_name] = response.headers[self.xcsrf_token_name]
@@ -95,7 +94,6 @@ class Requests:
                 response=response,
                 errors=errors
             )
-            print(exception)
             raise exception
         else:
             return response
